@@ -1,5 +1,7 @@
 from typing import Sequence
 
+from dataverk.utils.file_functions import url_encode
+
 
 class BaseView:
 
@@ -19,7 +21,7 @@ class BaseView:
         if not resources:
             self._resources = []
         else:
-            self._resources = resources
+            self._resources = [url_encode(resource) for resource in resources]
 
         if not name or len(name) is 0:
             self._name = title
